<body>
  {% for items_chunk in items_chunks %}
  <div class="print-area">
    {% for item_html in items_chunk %}
    <div class="item">{{ item_html }}</div>
    {% endfor %}
  </div>
  {% endfor %}
</body>

<style>
  @page {
    margin: 0;
  }
  body,
  html {
    margin: 0;
    padding: 0;
  }
</style>
