<div style="display:flex;flex-direction:column;height:100%">
  <div class="top">
    <div class="qr-code">
      <img src="{{label_tools.qr_code(pn_seq)}}"/>
    </div>
    <div class="metadata">
      <div class="thumbnail">
        <img src="file://{{ image }}" />
      </div>
      <div class="part-number">
        {{ pn }}
      </div>
    </div>
  </div>
  <div class="bottom">
    {{ name }}
  </div>
</div>
